@@ -21,6 +21,13 @@ class Packet:
     def __bytes__(self):
         return b"".join(proto for proto in self.__dict__.values())
 
+    def __repr__(self):
+        return ", ".join(repr(proto) for proto in vars(self).values())
+
     @property
-    def payload(self):
+    def payload(self) -> bytes:
         return self.__bytes__()
+
+    @property
+    def encapsulated_protos(self) -> tuple:
+        return tuple(proto for proto in vars(self).values())
